@@ -33,8 +33,11 @@ G_BEGIN_DECLS
 void            ringtoned_profile_init                  (void);
 
 const gchar *   ringtoned_profile_get_default_ringtone  (void);
+const gchar *   ringtoned_profile_get_cached_default_ringtone
+                                                        (void);
 gboolean        ringtoned_profile_is_default_ringtone   (const gchar *path);
-const gchar *   ringtoned_profile_get_playable_path     (const gchar *path);
+
+gint            ringtoned_profile_get_current_volume    (void);
 
 G_END_DECLS
 
