@@ -23,6 +23,7 @@
 #include "contact.h"
 #include <libringtoned/ringtoned.h>
 #include <string.h>
+#include "ringtone.h"
 
 
 #define PCR_CUSTOM_RINGTONE_FIELD "X-RINGTONED-RINGTONE-PATH"
@@ -59,7 +60,7 @@ typedef struct
 
     gchar *uid;
 
-    ContactUpdatedCallback cb;
+    PCRContactUpdatedCallback cb;
     gpointer user_data;
 } AttachClosure;
 
@@ -67,7 +68,7 @@ typedef struct
 {
     OssoABookContact *master;
 
-    ContactUpdatedCallback cb;
+    PCRContactUpdatedCallback cb;
     gpointer user_data;
 } UpdateClosure;
 
@@ -205,10 +206,10 @@ existing_master_committed_cb (EBook       *book,
 }
 
 void
-pcr_contact_set_custom_ringtone (OssoABookContact       *contact,
-                                 const gchar            *new_ringtone,
-                                 ContactUpdatedCallback  cb,
-                                 gpointer                user_data)
+pcr_contact_set_custom_ringtone (OssoABookContact          *contact,
+                                 const gchar               *new_ringtone,
+                                 PCRContactUpdatedCallback  cb,
+                                 gpointer                   user_data)
 {
     const gchar *current_ringtone;
     EVCardAttribute *attr;
@@ -223,7 +224,7 @@ pcr_contact_set_custom_ringtone (OssoABookContact       *contact,
             new_ringtone);
 
     current_ringtone = pcr_contact_get_custom_ringtone (contact);
-    if (g_strcmp0 (current_ringtone, new_ringtone) == 0)
+    if (pcr_ringtone_equal (current_ringtone, new_ringtone))
     {
         if (cb)
             cb (contact, E_BOOK_ERROR_OK, user_data);
@@ -282,6 +283,7 @@ pcr_contact_set_custom_ringtone (OssoABookContact       *contact,
             return;
         }
         rc = roster_contacts->data;
+        g_list_free (roster_contacts);
 
         new_contact = osso_abook_contact_new ();
 
