@@ -28,12 +28,15 @@
 #include <pulse/pulseaudio.h>
 #include <string.h>
 #include "contact.h"
+#include "ringtone.h"
+#include "i18n.h"
 
 
 enum
 {
     PROP_0,
-    PROP_RINGTONE
+    PROP_RINGTONE,
+    PROP_RINGTONE_NAME,
 };
 
 enum
@@ -48,8 +51,10 @@ struct _PCRRingtoneChooserPrivate
 {
     GtkListStore *store;
     GtkWidget *selector;
+    gboolean selection_changed_by_code;
 
     gchar *ringtone;
+    gchar *display_name;
 
     gboolean playing;
     GstElement *playbin;
@@ -187,9 +192,9 @@ start_preview (PCRRingtoneChooser *self)
     gtk_tree_model_get (GTK_TREE_MODEL (self->priv->store), &iter,
             COL_PATH, &preview_path, -1);
 
-    if (g_strcmp0 (preview_path, PCR_RINGTONE_DEFAULT) == 0)
+    if (pcr_ringtone_is_default (preview_path))
         DEBUG ("Not playing preview for default ringtone");
-    else if (g_strcmp0 (preview_path, PCR_RINGTONE_SILENT) == 0)
+    else if (pcr_ringtone_is_silent (preview_path))
         DEBUG ("Not playing preview for silent");
     else
         start_file (self, preview_path);
@@ -215,7 +220,10 @@ selector_changed_cb (HildonTouchSelector *widget,
                      PCRRingtoneChooser  *self)
 {
     stop_preview (self);
-    start_preview (self);
+    if (!self->priv->selection_changed_by_code)
+        start_preview (self);
+    else
+        DEBUG ("NOT PLAYING AS CHANGED BY CODE");
 }
 
 static void
@@ -245,7 +253,7 @@ find_ringtone_cb (GtkTreeModel *model,
     gchar *ringtone_path;
 
     gtk_tree_model_get (model, iter, COL_PATH, &ringtone_path, -1);
-    if (g_strcmp0 (ringtone_path, data->self->priv->ringtone) == 0)
+    if (pcr_ringtone_equal (ringtone_path, data->self->priv->ringtone))
     {
         data->iter = *iter;
         data->found = TRUE;
@@ -289,13 +297,49 @@ ensure_current_ringtone (PCRRingtoneChooser *self)
         g_free (display);
     }
 
+    self->priv->selection_changed_by_code = TRUE;
     hildon_touch_selector_select_iter (
             HILDON_TOUCH_SELECTOR (self->priv->selector), 0,
             &find_ringtone_data->iter, TRUE);
+    self->priv->selection_changed_by_code = FALSE;
 
     g_free (find_ringtone_data);
 }
 
+static void
+ringtone_changed (PCRRingtoneChooser *self)
+{
+    GtkTreeIter iter;
+    gchar *ringtone;
+
+    if (!get_selected_iter (self, &iter))
+        return;
+
+    g_free (self->priv->display_name);
+    gtk_tree_model_get (GTK_TREE_MODEL (self->priv->store), &iter,
+            COL_PATH, &ringtone,
+            COL_TEXT, &self->priv->display_name,
+            -1);
+
+    if (pcr_ringtone_is_default (ringtone))
+    {
+        g_free (self->priv->display_name);
+        self->priv->display_name = g_strdup (
+                _(PCR_RINGTONE_DEFAULT_DISPLAY_NAME));
+    }
+    else if (pcr_ringtone_is_silent (ringtone))
+    {
+        g_free (self->priv->display_name);
+        self->priv->display_name = g_strdup (
+                _(PCR_RINGTONE_SILENT_DISPLAY_NAME));
+    }
+
+    g_object_notify (G_OBJECT (self), "ringtone");
+    g_object_notify (G_OBJECT (self), "ringtone-name");
+
+    g_free (ringtone);
+}
+
 static void
 file_chooser_response_cb (GtkWidget          *chooser,
                           gint                response_id,
@@ -307,7 +351,7 @@ file_chooser_response_cb (GtkWidget          *chooser,
         self->priv->ringtone = gtk_file_chooser_get_filename (
                 GTK_FILE_CHOOSER (chooser));
         ensure_current_ringtone (self);
-        g_object_notify (G_OBJECT (self), "ringtone");
+        ringtone_changed (self);
     }
 
     gtk_widget_destroy (GTK_WIDGET (chooser));
@@ -322,7 +366,7 @@ show_file_chooser (PCRRingtoneChooser *self)
 
     chooser = hildon_file_chooser_dialog_new_with_properties (
             GTK_WINDOW (self),
-            "title", "Add tone",
+            "title", OSSO_PROFILES_GETTEXT ("profi_ti_open_sound_clip"),
             "action", GTK_FILE_CHOOSER_ACTION_OPEN,
             "local-only", TRUE,
             NULL);
@@ -354,6 +398,7 @@ set_ringtone_from_selection (PCRRingtoneChooser *self)
     g_free (self->priv->ringtone);
     gtk_tree_model_get (GTK_TREE_MODEL (self->priv->store), &iter,
             COL_PATH, &self->priv->ringtone, -1);
+    ringtone_changed (self);
 }
 
 static void
@@ -567,8 +612,8 @@ load_default_ringtones (PCRRingtoneChooser *self)
 static void
 fill_store (PCRRingtoneChooser *self)
 {
-    add_ringtone (self, "Default ringtone", PCR_RINGTONE_DEFAULT);
-    add_ringtone (self, "Silent", PCR_RINGTONE_SILENT);
+    add_ringtone (self, _("Default ringtone"), PCR_RINGTONE_DEFAULT);
+    add_ringtone (self, _("Silent"), PCR_RINGTONE_SILENT);
 
     load_default_ringtones (self);
 
@@ -608,11 +653,12 @@ pcr_ringtone_chooser_init (PCRRingtoneChooser *self)
 {
     self->priv = PCR_RINGTONE_CHOOSER_GET_PRIVATE (self);
 
-    gtk_window_set_title (GTK_WINDOW (self), "Ringing tone");
+    gtk_window_set_title (GTK_WINDOW (self),
+            OSSO_PROFILES_GETTEXT ("profi_ti_ringing_tone"));
 
     gtk_dialog_add_buttons (GTK_DIALOG (self),
-            "More", RESPONSE_MORE,
-            "Done", GTK_RESPONSE_OK,
+            HILDON_LIBS_GETTEXT ("wdgt_bd_add"), RESPONSE_MORE,
+            HILDON_LIBS_GETTEXT ("wdgt_bd_done"), GTK_RESPONSE_OK,
             NULL);
 
     g_signal_connect (self, "response", G_CALLBACK (response_cb), NULL);
@@ -654,6 +700,7 @@ pcr_ringtone_chooser_finalize (GObject *object)
         gst_object_unref (self->priv->playbin);
 
     g_free (self->priv->ringtone);
+    g_free (self->priv->display_name);
 
     G_OBJECT_CLASS (pcr_ringtone_chooser_parent_class)->finalize (object);
 }
@@ -671,6 +718,9 @@ pcr_ringtone_chooser_get_property (GObject    *object,
         case PROP_RINGTONE:
             g_value_set_string (value, self->priv->ringtone);
             break;
+        case PROP_RINGTONE_NAME:
+            g_value_set_string (value, self->priv->display_name);
+            break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
             break;
@@ -689,6 +739,7 @@ pcr_ringtone_chooser_set_property (GObject      *object,
     {
         case PROP_RINGTONE:
             self->priv->ringtone = g_value_dup_string (value);
+            ringtone_changed (self);
             break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -720,5 +771,15 @@ pcr_ringtone_chooser_class_init (PCRRingtoneChooserClass *klass)
                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
                 G_PARAM_STATIC_STRINGS));
 
+    g_object_class_install_property (
+            object_class,
+            PROP_RINGTONE_NAME,
+            g_param_spec_string (
+                "ringtone-name",
+                "Ringtone name",
+                "The display name of the ringtone",
+                "",
+                G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
     g_type_class_add_private (klass, sizeof (PCRRingtoneChooserPrivate));
 }
